pub fn init_pool(url: &str) -> ConnectionPoolsExpand description
Creates an initialized pool connecting to the database.
Panics
If the pool is unable to open its minimum number of connections.
pub fn init_pool(url: &str) -> ConnectionPoolsCreates an initialized pool connecting to the database.
If the pool is unable to open its minimum number of connections.